pub struct PkVHashmapWrapper { /* private fields */ }Expand description
A wrapper for std::collections::HashMap that implements the PkVariableAccessor trait.
Implementations
Sourceimpl PkVHashmapWrapper
impl PkVHashmapWrapper
Sourcepub fn new(
init_vec: Vec<(String, Option<Vec<u8>>, Box<dyn Fn(Vec<u8>)>)>,
) -> Self
pub fn new( init_vec: Vec<(String, Option<Vec<u8>>, Box<dyn Fn(Vec<u8>)>)>, ) -> Self
Creates a new PkVHashmapWrapper instance.
Arguments
init_vec: A vector of tuples, where each tuple contains:String: The variable key.Option<Vec<u8>>: The initial value of the variable. Defaults to an emptyVec<u8>ifNone.Box<dyn Fn(Vec<u8>) -> ()>: A listener function called when the variable is set.
IMPORTANT: The listener passed in here is synchronously executed and may block the main thread (where PkCommand::poll() is executed).
Use with caution or create a new thread if the listener is going to do something very costly.