Crate pk_command
Source - types
- PkCommand
- The main state machine for handling the PK Command protocol.
- PkCommandConfig
- Configuration for the
PkCommand state machine. - PkMHashmapWrapper
- A wrapper for
std::collections::HashMap that implements the PkMethodAccessor trait. - PkPollable
- A simple implementation of
Pollable based on multi-thread. - PkVHashmapWrapper
- A wrapper for
std::collections::HashMap that implements the PkVariableAccessor trait.
- PkMethodAccessor
- Trait defining how to invoke methods by their string key.
- PkVariableAccessor
- Trait defining how to access (get/set) variables by their string key.
- Pollable
- Trait defining the
poll method for a pk method which is invoked