pub struct PkCommandConfig { /* private fields */ }Expand description
Configuration for the PkCommand state machine.
Implementations
Sourceimpl PkCommandConfig
impl PkCommandConfig
Sourcepub fn default(packet_limit: u64) -> Self
pub fn default(packet_limit: u64) -> Self
Creates a PkCommandConfig with default timeout values.
Arguments
packet_limit: The maximum packet size allowed by the transport layer.
Sourcepub fn new(
ack_timeout: u64,
inter_command_timeout: u64,
await_interval: u64,
packet_limit: u64,
) -> Self
pub fn new( ack_timeout: u64, inter_command_timeout: u64, await_interval: u64, packet_limit: u64, ) -> Self
Creates a new PkCommandConfig with specified values.
Arguments
ack_timeout: ACK timeout in milliseconds.inter_command_timeout: Inter-command timeout in milliseconds.await_interval: AWAIT interval in milliseconds.packet_limit: The maximum packet size allowed by the transport layer.