pub struct PkPromise { /* private fields */ }Expand description
A simple implementation of Pollable based on multi-thread.
This is like Promise in JavaScript.
Implementations
Sourceimpl PkPromise
impl PkPromise
Sourcepub fn execute<T>(function: T) -> Pin<Box<Self>>
pub fn execute<T>(function: T) -> Pin<Box<Self>>
Creates a new PkPromise and executes a function in a new thread.
The provided function function will be executed in a separate thread.
It receives a resolve closure as an argument. The user’s function
should call this resolve closure with the result data (Vec<u8>)
when the asynchronous operation is complete.
Arguments
function: A closure that takes aresolveclosure and performs the asynchronous task. Theresolveclosure should be called with the result data when the task finishes successfully.
Returns
A new PkPromise instance that can be polled to check the status
of the asynchronous operation.