Pollable

Trait Pollable 

pub trait Pollable {
    // Required method
    fn poll(&self) -> Poll<Result<Option<Vec<u8>>, String>>;
}
Trait defining the poll method for a pk method which is invoked

This is designed for time-consuming tasks, like Future, but not for asynchronous programming. Ideal impletation may be multithreaded or something else that ensures the main thread not to be blocked.

Required Methods

Implementors