Module types
Source - Command
- Represents a parsed or to-be-sent PK Command.
- Operation
- Defines the set of operations supported by the PK Command protocol.
- Role
- Defines the role of a participant in a PK Command transaction.
- Stage
- Indicates the current stage of a transaction chain.
- Status
- Indicates the specific status of the command sender/receiver regarding acknowledgments.