Role

Enum Role 

pub enum Role {
    Host,
    Device,
    Idle,
}
Defines the role of a participant in a PK Command transaction.

This is used internally by the state machine to manage transaction flow and usually should not be used directly.

Variants



Host

The initiator of the transaction.



Device

The receiver and executor of the transaction.



Idle

Indicates that no transaction is active, and thus no specific role is assigned.