Struct Command
Source pub struct Command {
pub msg_id: u16,
pub operation: Operation,
pub object: Option<String>,
pub data: Option<Vec<u8>>,
}
Represents a parsed or to-be-sent PK Command.
Parses a byte slice into a Command struct.
The byte slice is expected to conform to the PK Command protocol format.
Arguments
msg_bytes: A byte slice representing the raw command.
Returns
A Result containing the parsed Command or a static string slice describing the error.
Serializes the Command struct into a Vec<u8> according to the PK Command protocol format.
Panics
Panics if self.msg_id is invalid and cannot be converted by msg_id::from_u16 (should not happen with valid IDs).
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Formats the value using the given formatter.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
Converts the given value to a
String.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.